@@ -240,10 +240,10 @@ Validate that a user in a remote MySQL server exists and has the password we exp
         arguments=[
             (['pk'], {'help': 'the name of the MySQL connection in deployfish.yml'}),
             (
-                ['--filename'],
+                ['--dumpfile'],
                 {
                     'help': 'Write the SQL dump to this file.',
-                    'default': False,
+                    'default': None,
                     'dest': 'filename',
                 }
             ),
